@@ -35,11 +35,12 @@
 #endif
 #include <stdio.h>
 
-#ifdef G_OS_WIN32
-#define SOEXT ".dll"
+#if USE_LA_MODULES
+#define SOEXT ".la"
 #else
-#define SOEXT ".so"
+#define SOEXT ("." G_MODULE_SUFFIX)
 #endif
+#define SOEXT_LEN (strlen (SOEXT))
 
 void 
 query_module (const char *dir, const char *name)
@@ -88,27 +89,27 @@ query_module (const char *dir, const char *name)
 	      quoted_path = g_strdup (path);
 	    }
 	  
-	  g_print ("%s%s%s %s %s %s ", quote, quoted_path, quote,
-		   engines[i].id, engines[i].engine_type, engines[i].render_type);
+	  printf ("%s%s%s %s %s %s ", quote, quoted_path, quote,
+		  engines[i].id, engines[i].engine_type, engines[i].render_type);
 	  g_free (quoted_path);
 
 	  for (j=0; j < engines[i].n_ranges; j++)
 	    {
 	      if (j != 0)
-		g_print (" ");
-	      g_print ("%d-%d:%s",
-		       engines[i].ranges[j].start,
-		       engines[i].ranges[j].end,
-		       engines[i].ranges[j].langs);
+		printf (" ");
+	      printf ("%d-%d:%s",
+		      engines[i].ranges[j].start,
+		      engines[i].ranges[j].end,
+		      engines[i].ranges[j].langs);
 	    }
-	  g_print ("\n");
-	  }
+	  printf ("\n");
+	}
     }
   else
     {
       fprintf (stderr, "%s does not export Pango module API\n", path);
     }
-
+  
   g_free (path);
   if (module)
     g_module_close (module);
@@ -132,6 +133,7 @@ int main (int argc, char **argv)
       path = pango_config_key_get ("Pango/ModulesPath");
       if (!path)
 	path = g_build_filename (pango_get_lib_subdirectory (),
+				 MODULE_VERSION,
 				 "modules",
 				 NULL);
 
@@ -149,7 +151,7 @@ int main (int argc, char **argv)
 	      while ((dent = g_dir_read_name (dir)))
 		{
 		  int len = strlen (dent);
-		  if (len > 3 && strcmp (dent + len - strlen (SOEXT), SOEXT) == 0)
+		  if (len > SOEXT_LEN && strcmp (dent + len - SOEXT_LEN, SOEXT) == 0)
 		    query_module (dirs[i], dent);
 		}
 	      
